set_color_with_cmap — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# set_color_with_cmap

Surface.set_color_with_cmap(cmap: str = 'viridis', vmin: float | None = None, vmax: float | None = None)

  Sets colors for the trimesh object using the color map provided

  Parameters:

    - cmap (string) – The colormap. The default is ‘viridis’.

    - vmin (float, optional) – The minimum normalizing value. The default is None.

    - vmax (float, optional) – The maximum normalizing value. The default is None.